@@ -3,8 +3,8 @@ package Mail::MtPolicyd;
 use strict;
 use base qw(Net::Server::PreFork);
 
-our $VERSION = '1.12'; # VERSION
-# ABSTRACT: the Mailteam policy daemon for postfix
+our $VERSION = '1.13'; # VERSION
+# ABSTRACT: a modular policy daemon for postfix
 
 use Data::Dumper;
 use Mail::MtPolicyd::Request;
@@ -121,12 +121,7 @@ sub configure {
 
 	$server->{'proto'} = 'tcp';
 	$server->{'host'} = '127.0.0.1';
-	$server->{'port'} = [
-		'127.0.0.1:12345',
-		'127.0.0.1:12346',
-		'127.0.0.1:12347',
-		'127.0.0.1:12348',
-	];
+	$server->{'port'} = [ '127.0.0.1:12345' ];
 
 	$server->{'min_servers'} = 4;
         $server->{'min_spare_servers'} = 4;
@@ -139,7 +134,7 @@ sub configure {
 	$self->{'keepalive_timeout'} = 60;
 	$self->{'max_keepalive'} = 0;
 
-	$self->{'db_dsn'} = 'dbi:mysql:mail';
+	$self->{'db_dsn'} = undef;
 	$self->{'db_user'} = '';
 	$self->{'db_password'} = '';
 
@@ -466,15 +461,15 @@ __END__
 
 =head1 NAME
 
-Mail::MtPolicyd - the Mailteam policy daemon for postfix
+Mail::MtPolicyd - a modular policy daemon for postfix
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 DESCRIPTION
 
-The mailteams postfix policy daemon
+Mail::MtPolicyd is the Net::Server class of the mtpolicyd daemon.
 
 =head2 SYNOPSIS
 
