@@ -2,7 +2,7 @@ package Mail::MtPolicyd::Client::Request;
 
 use Moose;
 
-our $VERSION = '1.12'; # VERSION
+our $VERSION = '1.13'; # VERSION
 # ABSTRACT: a postfix policyd client request class
 
 
@@ -36,7 +36,7 @@ sub new_from_fh {
         while( my $line = $fh->getline ) {
                 $line =~ s/\r?\n$//;
                 if( $line eq '') { $complete = 1 ; last; }
-                my ( $name, $value ) = split('=', $line);
+                my ( $name, $value ) = split('=', $line, 2);
                 if( ! defined $value ) {
                         die('error parsing response');
                 }
@@ -78,7 +78,7 @@ Mail::MtPolicyd::Client::Request - a postfix policyd client request class
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 DESCRIPTION
 
