@@ -3,13 +3,14 @@ package Mail::MtPolicyd::Plugin::DBL;
 use Moose;
 use namespace::autoclean;
 
-our $VERSION = '1.11'; # VERSION
+our $VERSION = '1.13'; # VERSION
 # ABSTRACT: mtpolicyd plugin for checking helo,sender domain,rdns against an DBL
 
 extends 'Mail::MtPolicyd::Plugin';
 with 'Mail::MtPolicyd::Plugin::Role::Scoring';
 with 'Mail::MtPolicyd::Plugin::Role::UserConfig' => {
-	'uc_attributes' => [ 'enabled' ],
+	'uc_attributes' => [ 'enabled', 'sender_mode', 'helo_name_mode',
+		'reverse_client_name_mode' ],
 };
 
 use Mail::MtPolicyd::Plugin::Result;
@@ -71,8 +72,8 @@ sub run {
 			$self->add_score($r, $self->name.'-'.$check => $self->$score_attr );
 		}
 
-		my $mode_field = $check.'_mode';
-		if( $self->$mode_field eq 'reject' ) {
+		my $mode = $self->get_uc( $session, $check.'_mode' );
+		if( $mode eq 'reject' ) {
 			return Mail::MtPolicyd::Plugin::Result->new(
 				action => $self->_get_reject_action($check, $hostname, $info),
 				abort => 1,
@@ -140,7 +141,7 @@ Mail::MtPolicyd::Plugin::DBL - mtpolicyd plugin for checking helo,sender domain,
 
 =head1 VERSION
 
-version 1.11
+version 1.13
 
 =head1 DESCRIPTION
 
@@ -164,11 +165,7 @@ Possible values: on,off
 
 If specified the give variable within the session will overwrite the value of 'enabled' if set.
 
-=item sender_mode (default: reject)
-
-=item helo_mode (default: passive)
-
-=item reverse_client_name_mode (default: reject)
+=item (uc_)sender_mode (default: reject), (uc_)helo_name_mode (default: passive), (uc_)reverse_client_name_mode (default: reject)
 
 Should the plugin return an reject if the check matches (reject) or
 just add an score (passive).
@@ -177,7 +174,7 @@ Possible values: reject, passive
 
 =item sender_score (default: 5)
 
-=item helo_score (default: 1)
+=item helo_name_score (default: 1)
 
 =item reverse_client_name_score (default: 2.5)
 
